@@ -149,19 +149,19 @@ class InternalAutoSolve:
                 self.ready = True
                 self.channel.start_consuming()
                 self.log("Stopped Message Consuming", self.autosolve_constants.SUCCESS)
-                self.emitter.emit("AutoSolveError", AutoSolveConnectionError.CONNECTION_CLOSED_UNEXPECTEDLY)
+                self.emitter.emit(self.autosolve_constants.ERROR_EVENT, AutoSolveConnectionError.CONNECTION_CLOSED_UNEXPECTEDLY)
             else:
                 self.log("Error with RabbitMQ connection, attempting to re-establish", self.autosolve_constants.WARNING)
                 self.handle_connection_error()
 
         except pika.exceptions.AMQPConnectionError or pika.exceptions.ConnectionClosedByBroker:
             self.log("Error with RabbitMQ connection, attempting to re-establish", self.autosolve_constants.WARNING)
-            self.emitter.emit("AutoSolveError", AutoSolveConnectionError.CONNECTION_ERROR_INIT)
+            self.emitter.emit(self.autosolve_constants.ERROR_EVENT, AutoSolveConnectionError.CONNECTION_ERROR_INIT)
             self.handle_connection_error()
 
         except Exception:
             self.log("Unknown error occurred during connection.", self.autosolve_constants.ERROR)
-            self.emitter.emit("AutoSolveError", AutoSolveConnectionError.CONNECTION_ERROR_INIT)
+            self.emitter.emit(self.autosolve_constants.ERROR_EVENT, AutoSolveConnectionError.CONNECTION_ERROR_INIT)
             self.handle_connection_error()
 
     def close_connection(self):
@@ -205,7 +205,7 @@ class InternalAutoSolve:
                                        on_message_callback=self.receive_message)
             return True
         except pika.exceptions.ChannelClosedByBroker:
-            self.emitter.emit("AutoSolveError", AutoSolveConnectionError.CONNECTION_ERROR_INIT)
+            self.emitter.emit(self.autosolve_constants.ERROR_EVENT, AutoSolveConnectionError.CONNECTION_ERROR_INIT)
 
     def receive_message(self, channel, method_frame, header_frame, body):
         if method_frame.routing_key == self.routing_key_receiver:
@@ -216,12 +216,12 @@ class InternalAutoSolve:
     def on_receiver_message(self, channel, method_frame, header_frame, body):
         json_string = "".join(chr(x) for x in body)
         self.log("Message Received: " + json_string, self.autosolve_constants.SUCCESS)
-        self.emitter.emit("AutoSolveResponse", json_string)
+        self.emitter.emit(self.autosolve_constants.RESPONSE_EVENT, json_string)
 
     def on_cancel_message(self, channel, method_frame, header_frame, body):
         json_string = "".join(chr(x) for x in body)
         self.log("Message Received: " + json_string, self.autosolve_constants.SUCCESS)
-        self.emitter.emit("AutoSolveResponse_Cancel", json_string)
+        self.emitter.emit(self.autosolve_constants.CANCEL_RESPONSE_EVENT, json_string)
 
     def handle_connection_error(self):
         self.connected = False
@@ -238,7 +238,7 @@ class InternalAutoSolve:
             self.attempt_message_backlog_send()
         else:
             self.log("Connection attempts unsuccessful", self.autosolve_constants.ERROR)
-            self.emitter.emit("AutoSolveError", AutoSolveConnectionError.CONNECTION_REESTABLISH_FAILED)
+            self.emitter.emit(self.autosolve_constants.ERROR_EVENT, AutoSolveConnectionError.CONNECTION_REESTABLISH_FAILED)
 
     def send(self):
         req = None
@@ -357,7 +357,7 @@ class InternalAutoSolve:
 
     def validate_connection(self):
         self.log("Validating input values with AutoSolve API", self.autosolve_constants.STATUS)
-        url = "https://dashboard.autosolve.io/rest/" + self.access_token + "/verify/" + self.api_key + "?clientId=" + self.client_key
+        url = "https://dash.autosolve.io/rest/" + self.access_token + "/verify/" + self.api_key + "?clientId=" + self.client_key
         response = requests.get(url)
         return response.status_code
 
